OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "¡No se puede escribir en la carpeta \"config\"!",
    "This can usually be fixed by giving the web server write access to the config directory." : "Esto usualmente se puede arreglar dándole al servidor web acceso de escritura a la carpeta config.",
    "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Pero, si prefieres mantener el archivo config.php como solo de lectura, establece la opción \"config_is_read_only\" a true en él.",
    "See %s" : "Ver %s",
    "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory." : "La aplicación %1$s no está presente o tiene una versión que no es compatible con este servidor. Por favor, chequee la carpeta de apps.",
    "Sample configuration detected" : "Configuración de ejemplo detectada",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Se ha detectado que el ejemplo de configuración ha sido copiado. Esto podría afectar a su instalación, por lo que no tiene soporte. Lea la documentación antes de hacer cambios en config.php",
    "The page could not be found on the server." : "La página no se ha encontrado en el servidor.",
    "%s email verification" : "%s verificación del correo electrónico",
    "Email verification" : "Verificación del correo electrónico",
    "Click the following button to confirm your email." : "Haz clic en el siguiente botón para confirmar tu correo electrónico.",
    "Click the following link to confirm your email." : "Haz clic en el siguiente enlace para confirmar tu correo electrónico.",
    "Confirm your email" : "Confirma tu correo electrónico",
    "Other activities" : "Otras actividades",
    "%1$s and %2$s" : "%1$s y %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s y %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s, y %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s y %5$s",
    "Education bundle" : "Paquete educativo",
    "Enterprise bundle" : "Pack para empresas",
    "Groupware bundle" : "Pack groupware",
    "Hub bundle" : "Pack para Hub",
    "Public sector bundle" : "Paquete del sector público",
    "Social sharing bundle" : "Pack para compartir en redes",
    "PHP %s or higher is required." : "Se requiere PHP %s o superior.",
    "PHP with a version lower than %s is required." : "Se necesita una versión de PHP inferior a %s",
    "%sbit or higher PHP required." : "Se requiere PHP %sbit o superior.",
    "The following architectures are supported: %s" : "Las siguientes arquitecturas están soportadas: %s",
    "The following databases are supported: %s" : "Las siguientes bases de datos están soportadas: %s",
    "The command line tool %s could not be found" : "No se encontró la herramienta %s de línea de comandos",
    "The library %s is not available." : "La biblioteca %s no está disponible",
    "Library %1$s with a version higher than %2$s is required - available version %3$s." : "Se requiere la biblioteca %1$s con una versión mayor que %2$s. Está disponible la versión %3$s.",
    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "Se requiere la biblioteca %1$s con una versión menor que %2$s. Está disponible la versión %3$s.",
    "The following platforms are supported: %s" : "Las siguientes plataformas están soportadas: %s",
    "Server version %s or higher is required." : "Se necesita la versión %s o superior del servidor.",
    "Server version %s or lower is required." : "Se necesita la versión %s o inferior del servidor.  ",
    "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "El usuario que ha iniciado sesión debe ser un administrador, un sub-administrador o haber obtenido permisos especiales para acceder a esta configuración",
    "Your current IP address doesn't allow you to perform admin actions" : "Su dirección IP actual no le permite ejecutar funciones de administrador",
    "Logged in account must be an admin or sub admin" : "La cuenta conectada debe ser de un administrador o un sub-administrador",
    "Logged in account must be an admin" : "La cuenta conectada debe ser un administrador",
    "Wiping of device %s has started" : "El borrado del dispositivo %s ha empezado",
    "Wiping of device »%s« has started" : "El borrado del dispositivo »%s« ha empezado",
    "»%s« started remote wipe" : "»%s« ha empezado el borrado a distancia",
    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "El dispositivo o la aplicación »%s« ha empezado el proceso de borrado a distancia. Vas a recibir otro mensaje por correo una vez que el proceso haya concluido.",
    "Wiping of device %s has finished" : "El borrado del dispositivo %s ha concluido",
    "Wiping of device »%s« has finished" : "El borrado del dispositivo »%s« ha concluido",
    "»%s« finished remote wipe" : "»%s« ha acabado el borrado a distancia",
    "Device or application »%s« has finished the remote wipe process." : "El dispositivo o la aplicación »%s« ha concluido el proceso de borrado a distancia.",
    "Remote wipe started" : "Borrado remoto comenzado.",
    "A remote wipe was started on device %s" : "Se ha iniciado un borrado remoto en el dispositivo %s.",
    "Remote wipe finished" : "Borrado remoto finalizado",
    "The remote wipe on %s has finished" : "El borrado remoto en %s ha finalizado",
    "Authentication" : "Autentificación",
    "Unknown filetype" : "Tipo de archivo desconocido",
    "Invalid image" : "Imagen no válida",
    "Avatar image is not square" : "La imagen de avatar no es cuadrada",
    "Files" : "Archivos",
    "View profile" : "Ver perfil",
    "same time" : "al mismo tiempo",
    "_%nh_::_%nh_" : ["%nh","%nh","%nh"],
    "_%nm_::_%nm_" : ["%n m","%n m","%n m"],
    "%s ahead" : "%s adelantado",
    "%s behind" : "%s atrasado",
    "Local time: %s" : "Hora local: %s",
    "today" : "hoy",
    "tomorrow" : "mañana",
    "yesterday" : "ayer",
    "_in %n day_::_in %n days_" : ["dentro de %n día","dentro de %n días","dentro de %n días"],
    "_%n day ago_::_%n days ago_" : ["Hace %n día","hace %n días","hace %n días"],
    "next month" : "mes siguiente",
    "last month" : "mes pasado",
    "_in %n month_::_in %n months_" : ["dentro de %n mes","dentro de %n meses","dentro de %n meses"],
    "_%n month ago_::_%n months ago_" : ["Hace %n mes","hace %n meses","hace %n meses"],
    "next year" : "año que viene",
    "last year" : "año pasado",
    "_in %n year_::_in %n years_" : ["dentro de %n año","dentro de %n años","dentro de %n años"],
    "_%n year ago_::_%n years ago_" : ["Hace %n año","hace %n años","hace %n años"],
    "_in %n hour_::_in %n hours_" : ["dentro de %n hora","dentro de %n horas","dentro de %n horas"],
    "_%n hour ago_::_%n hours ago_" : ["Hace %n hora","hace %n horas","hace %n horas"],
    "_in %n minute_::_in %n minutes_" : ["dentro de %n minuto","dentro de %n minutos","dentro de %n minutos"],
    "_%n minute ago_::_%n minutes ago_" : ["Hace %n minuto","hace %n minutos","hace %n minutos"],
    "in a few seconds" : "en unos segundos",
    "seconds ago" : "hace segundos",
    "Empty file" : "Archivo vacío",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "El módulo con ID %s no existe. Por favor, actívalo en la configuración de apps o contacta con tu administrador.",
    "No file conversion providers available" : "No hay proveedores de conversión de archivos disponibles",
    "File is too large to convert" : "El archivo es demasiado grande para convertir",
    "Destination does not match conversion extension" : "El destino no coincide con la extensión convertida",
    "Could not convert file" : "No se ha podido convertir el archivo",
    "Destination does not exist" : "El destino no existe",
    "Destination is not creatable" : "El destino no se puede crear",
    "Dot files are not allowed" : "Los archivos Dot no están permitidos",
    "\"%1$s\" is a forbidden file or folder name." : "\"%1$s\" Es un nombre de archivo o carpeta no permitido.",
    "\"%1$s\" is a forbidden prefix for file or folder names." : "%1$s es un prefijo prohibido para nombres de archivo o carpeta.",
    "\"%1$s\" is not allowed inside a file or folder name." : "«%1$s» no se permite en el nombre de un archivo o carpeta.",
    "\"%1$s\" is a forbidden file type." : "\"%1$s\" es un tipo de archivo no permitido.",
    "Filenames must not end with \"%1$s\"." : "Los nombres de archivos no deben terminar con \"%1$s\".",
    "Invalid parent path" : "Ruta de nivel superior inválida",
    "File already exists" : "El archivo ya existe",
    "Invalid path" : "Ruta no válida",
    "Failed to create file from template" : "Fallo al crear el archivo desde plantilla",
    "Templates" : "Plantillas",
    "Storage %s cannot be moved" : "El almacenamiento %s no ha podido moverse",
    "Moving a share (%s) into a shared folder is not allowed" : "No está permitido mover un recurso compartido (%s) a una carpeta compartida",
    "Moving a storage (%s) into a shared folder is not allowed" : "No está permitido mover un almacenamiento (%s) a una carpeta compartida",
    "Moving a share (%s) into another share (%s) is not allowed" : "No está permitido mover un recurso compartido (%s) a otro recurso compartido (%s)",
    "Moving a share (%s) into another storage (%s) is not allowed" : "No está permitido mover un recurso compartido (%s) a otro almacenamiento (%s)",
    "Moving a storage (%s) into a share (%s) is not allowed" : "No está permitido mover un almacenamiento (%s) a un recurso compartido (%s)",
    "Moving a storage (%s) into another storage (%s) is not allowed" : "No está permitido mover un almacenamiento (%s) a otro almacenamiento (%s)",
    "Path contains invalid segments" : "La ruta contiene segmentos inválidos",
    "Filename is a reserved word" : "El nombre de archivo es una palabra reservada",
    "Filename contains at least one invalid character" : "El nombre de archivo contiene al menos un carácter inválido",
    "Filename is too long" : "El nombre del archivo es demasiado largo",
    "Empty filename is not allowed" : "No se puede dejar el nombre en blanco.",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "No se puede instalar la app \"%s\" debido a que no se puede leer la información de la app.",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "No se puede instalar la aplicación \"%s\" porque no es compatible con esta versión del servidor.",
    "__language_name__" : "Español (España)",
    "This is an automatically sent email, please do not reply." : "Este es un correo enviado automáticamente, por favor no responda.",
    "Help & privacy" : "Ayuda y privacidad",
    "Appearance and accessibility" : "Apariencia y accesibilidad",
    "Apps" : "Aplicaciones",
    "Personal settings" : "Ajustes personales",
    "Administration settings" : "Configuraciones de administración",
    "Settings" : "Ajustes",
    "Log out" : "Cerrar sesión",
    "Accounts" : "Cuentas",
    "Email" : "Correo electrónico",
    "Mail %s" : "Correo %s",
    "Fediverse" : "Fediverso",
    "View %s on the fediverse" : "Ver %s en el fediverso",
    "Phone" : "Teléfono",
    "Call %s" : "Llamada %s",
    "Twitter" : "Twitter",
    "View %s on Twitter" : "Ver %s en Twitter",
    "Website" : "Sitio web",
    "Visit %s" : "Visita %s",
    "Address" : "Dirección",
    "Profile picture" : "Imagen de perfil",
    "About" : "Acerca de",
    "Display name" : "Nombre para mostrar",
    "Headline" : "Titular",
    "Organisation" : "Organización",
    "Role" : "Puesto",
    "Pronouns" : "Pronombres",
    "Unknown account" : "Cuenta desconocida",
    "Additional settings" : "Configuración adicional",
    "Enter the database Login and name for %s" : "Ingrese el usuario y el nombre para la base de datos %s",
    "Enter the database Login for %s" : "Ingrese el usuario de la base de datos para %s",
    "Enter the database name for %s" : "Introduzca el nombre de la base de datos %s",
    "You cannot use dots in the database name %s" : "No puede utilizar puntos para el nombre de base de datos %s",
    "MySQL Login and/or password not valid" : "Usuario y/o contraseña de MySQL inválidos",
    "You need to enter details of an existing account." : "Necesita introducir los datos de una cuenta existente.",
    "Oracle connection could not be established" : "No se pudo establecer la conexión a Oracle",
    "Oracle Login and/or password not valid" : "Usuario y/o contraseña de Oracle inválidos",
    "PostgreSQL Login and/or password not valid" : "Usuario y/o contraseña de PostgreSQL inválidos",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk!" : "Mac OS X no está soportado y %s no funcionará bien en esta plataforma. ¡Úsela bajo su propio riesgo! ",
    "For the best results, please consider using a GNU/Linux server instead." : "Para obtener los mejores resultados, considera utilizar un servidor GNU/Linux.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Parece que esta instancia %s está funcionando en un entorno PHP de 32-bits y el open_basedir se ha configurado en php.ini. Esto acarreará problemas con archivos de tamaño superior a 4GB y resulta totalmente desaconsejado.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Por favor, quite el ajuste de open_basedir —dentro de su php.ini— o pásese a PHP de 64 bits.",
    "Set an admin Login." : "Establecer un usuario administrador.",
    "Set an admin password." : "Configurar la contraseña del administrador.",
    "Cannot create or write into the data directory %s" : "No se puede crear o escribir en la carpeta de datos %s",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "El motor compartido %s debe implementar la interfaz OCP\\Share_Backend",
    "Sharing backend %s not found" : "El motor compartido %s no se ha encontrado",
    "Sharing backend for %s not found" : "Motor compartido para %s no encontrado",
    "%1$s shared %2$s with you" : "%1$s ha compartido %2$s contigo",
    "Open %s" : "Abrir %s",
    "%1$s via %2$s" : "%1$s vía %2$s",
    "%1$s shared %2$s with you and wants to add:" : "%1$s ha compartido %2$s contigo y quiere añadir:",
    "%1$s shared %2$s with you and wants to add" : "%1$s ha compartido %2$s contigo y quiere añadir",
    "%s added a note to a file shared with you" : "%s ha añadido una nota a un archivo compartido contigo",
    "Passwords are enforced for link and mail shares" : "Las contraseñas son obligatorias para los enlaces y correos compartidos.",
    "Share recipient is not a valid user" : "El recipiente del recurso compartido no es un usuario válido",
    "Share recipient is not a valid group" : "El recipiente del recurso compartido no es un grupo válido",
    "Share recipient should be empty" : "El recipiente del recurso compartido debería estar vacío",
    "Share recipient should not be empty" : "El recipiente del recurso compartido no debería estar vacío",
    "Share recipient is not a valid circle" : "El recipiente del recurso compartido no es un círculo válido",
    "Unknown share type" : "Tipo de recurso compartido desconocido",
    "Share initiator must be set" : "Se debe especificar el iniciador del recurso compartido",
    "Cannot share with yourself" : "No puede compartir consigo mismo",
    "Shared path must be set" : "La ruta del recurso compartido debe ser establecida",
    "Shared path must be either a file or a folder" : "La ruta compartida debe ser o bien un archivo o una carpeta",
    "You cannot share your root folder" : "No puede compartir su carpeta raíz",
    "You are not allowed to share %s" : "Usted no está autorizado para compartir %s",
    "Valid permissions are required for sharing" : "Se requieren permisos válidos para compartir",
    "File shares cannot have create or delete permissions" : "Las recursos compartidos de archivos no pueden tener permisos de creación o borrado",
    "Cannot increase permissions of %s" : "No se pueden incrementar los permisos de %s",
    "Shares need at least read permissions" : "Los recursos compartidos requieren al menos permisos de lectura",
    "Files cannot be shared with delete permissions" : "Los archivos no se pueden compartir con permisos de borrado",
    "Files cannot be shared with create permissions" : "Los archivos no se pueden compartir con permisos de creación",
    "Expiration date is in the past" : "Ha pasado la fecha de caducidad",
    "Expiration date is enforced" : "La fecha de caducidad es obligatoria",
    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["No se puede fijar la fecha de caducidad más de %n día en el futuro.","No se puede fijar la fecha de caducidad más de %n días en el futuro.","No se puede fijar la fecha de caducidad más de %n días en el futuro."],
    "Sharing is only allowed with group members" : "Sólo está permitido compartir a los integrantes del grupo",
    "Sharing %s failed, because this item is already shared with the account %s" : "No se pudo compartir %s porque este elemento ya está compartido con el usuario %s",
    "Group sharing is now allowed" : "La compartición con grupos está ahora permitida",
    "Sharing is only allowed within your own groups" : "Solo le es posible compartir con sus propios grupos",
    "Path is already shared with this group" : "La ruta ya se encuentra compartida con este grupo",
    "Link sharing is not allowed" : "La compartición de enlaces no está permitida",
    "Public upload is not allowed" : "No está permitida la subida de archivos pública",
    "You cannot share a folder that contains other shares" : "No puede compartir una carpeta que contiene otros recursos compartidos",
    "Sharing is disabled" : "Compartir está deshabilitado",
    "Sharing is disabled for you" : "Compartir está deshabilitado para Ud.",
    "Cannot share with the share owner" : "No se puede compartir con el propietario del recurso compartido",
    "Share does not have a full ID" : "El recurso compartido no tiene un ID completo",
    "Cannot change share type" : "No es posible cambiar el tipo de recurso compartido",
    "Can only update recipient on user shares" : "Sólo puede actualizarse el recipiente en recursos compartidos de usuario",
    "Cannot enable sending the password by Talk with an empty password" : "No puede habilitarse el envío de contraseñas via Talk utilizando una contraseña en blanco",
    "Cannot enable sending the password by Talk without setting a new password" : "No puede habilitarse el envío de contraseñas via Talk sin establecer una nueva contraseña",
    "Cannot disable sending the password by Talk without setting a new password" : "No puede deshabilitar el envío de contraseñas via Talk sin establecer una nueva contraseña",
    "Share provider does not support accepting" : "El proveedor de recursos compartidos no soporta la aceptación",
    "Cannot change target of link share" : "No puede cambiarse el destino del enlace compartido",
    "Invalid share recipient" : "Recipiente de recurso compartido inválido",
    "Group \"%s\" does not exist" : "El grupo \"%s\" no existe",
    "The requested share does not exist anymore" : "El recurso compartido solicitado ya no existe",
    "The requested share comes from a disabled user" : "El recurso compartido solicitado proviene de un usuario deshabilitado",
    "The user was not created because the user limit has been reached. Check your notifications to learn more." : "El usuario no fue creado ya que el límite de usuarios fue alcanzado. Compruebe sus notificaciones para aprender más.",
    "Could not find category \"%s\"" : "No puede encontrar la categoría \"%s\"",
    "Input text" : "Texto de entrada",
    "The input text" : "El texto de entrada",
    "Sunday" : "Domingo",
    "Monday" : "Lunes",
    "Tuesday" : "Martes",
    "Wednesday" : "Miércoles",
    "Thursday" : "Jueves",
    "Friday" : "Viernes",
    "Saturday" : "Sábado",
    "Sun." : "Dom.",
    "Mon." : "Lun.",
    "Tue." : "Mar.",
    "Wed." : "Mié.",
    "Thu." : "Jue.",
    "Fri." : "Vie.",
    "Sat." : "Sáb.",
    "Su" : "Do",
    "Mo" : "Lu",
    "Tu" : "Ma",
    "We" : "Mi",
    "Th" : "Ju",
    "Fr" : "Vi",
    "Sa" : "Sa",
    "January" : "enero",
    "February" : "febrero",
    "March" : "marzo",
    "April" : "abril",
    "May" : "mayo",
    "June" : "junio",
    "July" : "julio",
    "August" : "agosto",
    "September" : "septiembre",
    "October" : "octubre",
    "November" : "noviembre",
    "December" : "diciembre",
    "Jan." : "Ene.",
    "Feb." : "Feb.",
    "Mar." : "Mar.",
    "Apr." : "Abr.",
    "May." : "May.",
    "Jun." : "Jun.",
    "Jul." : "Jul.",
    "Aug." : "Ago.",
    "Sep." : "Sep.",
    "Oct." : "Oct.",
    "Nov." : "Nov.",
    "Dec." : "Dic.",
    "A valid password must be provided" : "Se debe proporcionar una contraseña válida",
    "The Login is already being used" : "La cuenta ya está en uso",
    "Could not create account" : "No se pudo crear la cuenta",
    "Only the following characters are allowed in an Login: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Sólo los siguientes caracteres están permitidos en un nombre de usuario: \"a-z\", \"A-Z\", \"0-9\", espacios y \"_.@-'\"",
    "A valid Login must be provided" : "Se debe proporcionar un usuario válido",
    "Login contains whitespace at the beginning or at the end" : "El usuario contiene espacios en blanco al inicio o al final",
    "Login must not consist of dots only" : "El usuario no debe consistir sólo de puntos",
    "Login is invalid because files already exist for this user" : "El nombre de inicio de sesión es inválido porque ya existen archivos para este usuario",
    "Account disabled" : "Cuenta deshabilitada",
    "Login canceled by app" : "Login cancelado por la app",
    "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "No se ha podido instlaar la app «%1$s» porque no se cumplen las siguientes dependencias: %2$s",
    "a safe home for all your data" : "un hogar seguro para todos tus datos",
    "Application is not enabled" : "La aplicación no está habilitada",
    "Authentication error" : "Error de autenticación",
    "Token expired. Please reload page." : "Token caducado. Por favor, recarge la página.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "No están instalados los drivers de BBDD  (sqlite, mysql, o postgresql)",
    "Cannot write into \"config\" directory." : "No se puede escribir en la carpeta \"config\".",
    "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Esto usualmente se puede arreglar dándole al servidor web acceso de escritura a la carpeta config.%s",
    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "O, si prefieres mantener el archivo config.php como de solo lectura, marca la opción \"config_is_read_only\" a 'true' en él. Ver %s",
    "Cannot write into \"apps\" directory." : "No se puede escribir en la carpeta \"apps\".",
    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Esto usualmente se puede arreglar dándole al servidor web acceso de escritura a la carpeta de apps o deshabilitando el App Store en el archivo de configuración.",
    "Cannot create \"data\" directory." : "No se puede crear la carpeta \"data\"",
    "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Esto usualmente se puede arreglar dándole al servidor web acceso de escritura a la carpeta raíz. Véase %s",
    "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Los permisos pueden arreglase usualmente dando al servidor web acceso de escritura a la carpeta raíz. Véase %s.",
    "Your data directory is not writable." : "Su carpeta de datos no tiene permisos de escritura",
    "Setting locale to %s failed." : "Fallo al configurar el idioma a %s.",
    "Please install one of these locales on your system and restart your web server." : "Por favor, instale uno de estos idiomas en su sistema y reinicie su servidor web.",
    "PHP module %s not installed." : "El módulo PHP %s no está instalado.",
    "Please ask your server administrator to install the module." : "Consulte al administrador de su servidor para instalar el módulo.",
    "PHP setting \"%s\" is not set to \"%s\"." : "La opción PHP \"%s\" no es \"%s\".",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "Ajustar esta configuración en php.ini hará que Nextcloud funcione de nuevo",
    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> está establecido como <code>%s</code> en lugar del valor esperado: <code>0</code>.",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Para arreglar este problema, establezca <code>mbstring.func_overload</code> en<code>0</code> en su php.ini.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP está aparentemente configurado para eliminar bloques de documentos en línea. Esto hará que varias aplicaciones principales estén inaccesibles.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Probablemente esto venga a causa de la caché o un acelerador, tales como Zend OPcache o eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "Los módulos PHP se han instalado, pero aparecen listados como si faltaran",
    "Please ask your server administrator to restart the web server." : "Consulte al administrador de su servidor para reiniciar el servidor web.",
    "The required %s config variable is not configured in the config.php file." : "La variable de configuración %s requerida no está configurada en el archivo config.php.",
    "Please ask your server administrator to check the Nextcloud configuration." : "Por favor, pida al administrador de su servidor que compruebe la configuración de Nextcloud.",
    "Your data directory is readable by other people." : "Su directorio de datos puede ser leído por otros usuarios.",
    "Please change the permissions to 0770 so that the directory cannot be listed by other people." : "Por favor, cambie los permisos a 0770 para que el directorio no se pueda listado por otros usuarios.",
    "Your data directory must be an absolute path." : "Su carpeta de datos debe ser una ruta absoluta.",
    "Check the value of \"datadirectory\" in your configuration." : "Compruebe el valor de «datadirectory» en su configuración.",
    "Your data directory is invalid." : "Su carpeta de datos es inválida.",
    "Ensure there is a file called \"%1$s\" in the root of the data directory. It should have the content: \"%2$s\"" : "Asegúrese que exista un archivo llamado \"%1$s\" en la raíz del directorio de datos. Debería contener: \"%2$s\"",
    "Action \"%s\" not supported or implemented." : "La acción \"%s\" no está soportada o implementada.",
    "Authentication failed, wrong token or provider ID given" : "La autentificación ha fallado. Se ha proporcionado un token o una ID de proveedor erróneos.",
    "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Faltan parámetros para completar la petición. Parámetros que faltan: \"%s\"",
    "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "La ID  «%1$s» ya está siendo usada por el proveedor de federación en la nube  «%2$s»",
    "Cloud Federation Provider with ID: \"%s\" does not exist." : "El proveedor de nube federada con ID \"%s\" no existe.",
    "Could not obtain lock type %d on \"%s\"." : "No se pudo realizar el bloqueo %d en \"%s\".",
    "Storage unauthorized. %s" : "Almacenamiento no autorizado. %s",
    "Storage incomplete configuration. %s" : "Configuración de almacenamiento incompleta. %s",
    "Storage connection error. %s" : "Error de conexión de almacenamiento. %s",
    "Storage is temporarily not available" : "El almacenamiento no esta disponible temporalmente",
    "Storage connection timeout. %s" : "Tiempo de conexión de almacenamiento agotado. %s",
    "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule." : "Para permitir que este chequeo se lleve a cabo, debe asegurarse que su servidor pueda conectarse a sí mismo. Por tanto, este debe poder resolver y conectarse a alguno de sus `trusted_domains` o al url definido en `overwrite.cli.url`. Este fallo puede ser resultado de una inconsistencia DNS del lado del servidor o una regla de salida del cortafuegos.",
    "Transcribe audio" : "Transcribir audio",
    "Transcribe the things said in an audio" : "Transcribir las cosas que se dicen en un audio",
    "Audio input" : "Entrada de audio",
    "The audio to transcribe" : "El audio a transcribir",
    "Transcription" : "Transcripción",
    "The transcribed text" : "El texto transcrito",
    "Chat with an agent" : "Chatea con un agente",
    "Chat message" : "Mensaje de chat",
    "A chat message to send to the agent." : "Un mensaje de chat a escribir al agente",
    "Confirmation" : "Confirmación",
    "Whether to confirm previously requested actions: 0 for denial and 1 for confirmation." : "Si se deben confirmar acciones solicitadas anteriormente: 0 para denegar y 1 para confirmar.",
    "Conversation token" : "Token de conversación",
    "A token representing the conversation." : "Un token que representa la conversación.",
    "Generated response" : "Respuesta generada",
    "The response from the chat model." : "La respuesta del modelo de chat.",
    "The new conversation token" : "El nuevo token de conversación",
    "Send this along with the next interaction." : "Envía esto junto a la siguiente interacción.",
    "Requested actions by the agent" : "Acciones solicitadas por el agente",
    "Actions that the agent would like to carry out in JSON format." : "Acciones que el agente quiere realizar en formato JSON.",
    "Context write" : "Escribir contexto",
    "Writes text in a given style based on the provided source material." : "Escribe el texto en un estilo dado basándose en el material fuente proporcionado.",
    "Writing style" : "Estilo de escritura",
    "Demonstrate a writing style that you would like to immitate" : "Demuestre un estilo de escritura que le gustaría imitar",
    "Source material" : "Material fuente",
    "The content that would like to be rewritten in the new writing style" : "El contenido que desea sea reescrito en un nuevo estilo de escritura",
    "Generated text" : "Texto generado",
    "The generated text with content from the source material in the given style" : "El texto generado con el contenido del material fuente en el estilo dado",
    "Emoji generator" : "Generador de emojis",
    "Takes text and generates a representative emoji for it." : "Toma un texto y genera un emoji representativo para éste.",
    "The text to generate an emoji for" : "El texto para el cual se generará un emoji",
    "Generated emoji" : "Emoji generado",
    "The generated emoji based on the input text" : "El emoji generado basado en el texto de entrada",
    "Generate image" : "Generar imagen",
    "Generate an image from a text prompt" : "Generar una imagen desde un prompt de texto",
    "Prompt" : "Prompt",
    "Describe the image you want to generate" : "Describa la imagen que quiere generar",
    "Number of images" : "Número de imágenes",
    "How many images to generate" : "Cuántas imágenes se generarán",
    "Output images" : "Imágenes de salida",
    "The generated images" : "Las imágenes generadas",
    "Free text to text prompt" : "Texto libre a prompt de texto",
    "Runs an arbitrary prompt through a language model that returns a reply" : "Ejecuta un prompt arbitrario a través de un modelo de lenguaje que retorna una respuesta",
    "Describe a task that you want the assistant to do or ask a question" : "Describa una tarea que quiere que el asistente realice, o, haga una pregunta",
    "Generated reply" : "Respuesta generada",
    "The generated text from the assistant" : "El texto generado por el asistente",
    "Change Tone" : "Cambiar tono",
    "Change the tone of a piece of text." : "Cambiar el tono de un texto.",
    "Write a text that you want the assistant to rewrite in another tone." : "Escribe un texto que quieres que el asistente reescriba en otro tono",
    "Desired tone" : "Tono deseado",
    "In which tone should your text be rewritten?" : "¿En qué tono debe reescribirse tu texto?",
    "The rewritten text in the desired tone, written by the assistant:" : "El texto reescrito en el tono deseado, escrito por el asistente:",
    "Chat" : "Chat",
    "Chat with the assistant" : "Chatear con el asistente",
    "System prompt" : "Prompt del sistema",
    "Define rules and assumptions that the assistant should follow during the conversation." : "Definir las reglas y supuestos que el asistente debe seguir durante la conversación.",
    "Chat history" : "Historial de la conversación",
    "The history of chat messages before the current message, starting with a message by the user" : "El historial de mensajes del chat antes del mensaje actual, empezando con un mensaje del usuario",
    "Response message" : "Mensaje de respuesta",
    "The generated response as part of the conversation" : "La respuesta generada como parte de la conversación",
    "Chat with tools" : "Chat con herramientas:",
    "Chat with the language model with tool calling support." : "Cheatea con el modelo de lenguaje con capacidad para llamar a herramientas.",
    "Tool message" : "Mensaje de herramienta",
    "The result of tool calls in the last interaction" : "El resultado de llamada a herramientas de la última interacción",
    "Available tools" : "Herramientas disponibles",
    "The available tools in JSON format" : "Las herramientas disponibles en formato JSON",
    "The response from the chat model" : "La respuesta del modelo de chat",
    "Tool calls" : "Llamadas a herramientas",
    "Tools call instructions from the model in JSON format" : "Instrucciones para llamadas a herramientas del modelo en formato JSON",
    "Formalize text" : "Formalizar texto",
    "Takes a text and makes it sound more formal" : "Toma un texto y lo hace sonar más formal",
    "Write a text that you want the assistant to formalize" : "Escriba un texto que quiere que el asistente formalice",
    "Formalized text" : "Texto formalizado",
    "The formalized text" : "El texto formalizado",
    "Generate a headline" : "Generar un titular",
    "Generates a possible headline for a text." : "Genera un posible titular para un texto.",
    "Original text" : "Texto original",
    "The original text to generate a headline for" : "El texto original para el cual generar un titular",
    "The generated headline" : "El titular generado",
    "Proofread" : "Corregir",
    "Proofreads a text and lists corrections" : "Corrige un texto y muestra sugerencias",
    "Text" : "Texto",
    "The text to proofread" : "El texto a corregir",
    "Corrections" : "Correcciones",
    "The corrections that should be made in your text" : "Las correcciones que deberían aplicarse a tu texto",
    "Reformulate text" : "Reformular texto",
    "Takes a text and reformulates it" : "Toma un texto y lo reformula",
    "Write a text that you want the assistant to reformulate" : "Escriba un texto que quiere que el asistente reformule",
    "Reformulated text" : "Texto reformulado",
    "The reformulated text, written by the assistant" : "El texto reformulado, escrito por el asistente",
    "Simplify text" : "Simplificar texto",
    "Takes a text and simplifies it" : "Toma un texto y lo simplifica",
    "Write a text that you want the assistant to simplify" : "Escriba un texto que quiere que el asistente simplifique",
    "Simplified text" : "Texto simplificado",
    "The simplified text" : "El texto simplificado",
    "Summarize" : "Resumir",
    "Summarizes a text" : "Resume un texto",
    "The original text to summarize" : "El texto original a resumir",
    "Summary" : "Resumen",
    "The generated summary" : "El resumen generado",
    "Extract topics" : "Extraer tópicos",
    "Extracts topics from a text and outputs them separated by commas" : "Extrae los tópicos de un texto y genera una salida separada por comas.",
    "The original text to extract topics from" : "El texto original desde donde extraer los tópicos",
    "Topics" : "Tópicos",
    "The list of extracted topics" : "La lista de tópicos extraídos",
    "Translate" : "Traducir",
    "Translate text from one language to another" : "Traducir texto de un lenguaje a otro",
    "Origin text" : "Texto de origen",
    "The text to translate" : "El texto a traducir",
    "Origin language" : "Lenguaje origen",
    "The language of the origin text" : "El lenguaje del texto de origen",
    "Target language" : "Lenguaje de destino",
    "The desired language to translate the origin text in" : "El lenguaje al que se desea traducir el texto de origen",
    "Result" : "Resultado",
    "The translated text" : "El texto traducido",
    "Free prompt" : "Prompt libre",
    "Runs an arbitrary prompt through the language model." : "Ejecuta un prompt arbitrario mediante el modelo de lenguaje.",
    "Generate headline" : "Generar titular",
    "Summarizes text by reducing its length without losing key information." : "Resume el texto reduciendo su longitud sin perder información clave.",
    "Extracts topics from a text and outputs them separated by commas." : "Extrae los tópicos de un texto y genera una salida separada por comas. ",
    "Education Edition" : "Edición Educación",
    "File name is a reserved word" : "El nombre de archivo es una palabra reservada",
    "File name contains at least one invalid character" : "El nombre del archivo contiene al menos un carácter inválido",
    "File name is too long" : "El nombre del archivo es demasiado largo",
    "Users" : "Usuarios",
    "%1$s shared »%2$s« with you and wants to add:" : "%1$s ha compartido «%2$s» contigo y quiere añadir:",
    "%1$s shared »%2$s« with you and wants to add" : "%1$s ha compartido «%2$s» contigo y quiere añadir",
    "»%s« added a note to a file shared with you" : "«%s» ha añadido una nota a un archivo compartido contigo",
    "Open »%s«" : "Abrir »%s« ",
    "%1$s shared »%2$s« with you" : "%1$s ha compartido «%2$s» contigo",
    "%1$s shared »%2$s« with you." : "%1$s ha compartido «%2$s» contigo.",
    "Click the button below to open it." : "Haz clic en el botón de abajo para abrirlo.",
    "File is currently busy, please try again later" : "El archivo se encuentra actualmente ocupado, por favor inténtelo de nuevo más tarde",
    "Cannot download file" : "No se puede descargar el archivo",
    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Asegúrate de que existe un archivo llamado \".ocdata\" en la raíz del directorio de datos."
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
